==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/TSCodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { CodeGeneratingComponentRendererModuleEmitter } from "./CodeGeneratingComponentRendererModuleEmitter";
import { Dictionary$2 } from "./Dictionary$2";
import { List$1 } from "./List$1";
import { String_$type, fromEnum, markType } from "./type";
import { stringEndsWith } from "./string";
/**
 * @hidden
 */
var TSCodeGeneratingComponentRendererModuleEmitter = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TSCodeGeneratingComponentRendererModuleEmitter, _super);
    function TSCodeGeneratingComponentRendererModuleEmitter(a, b, c) {
        var _this = _super.call(this, b, c) || this;
        _this.o = 0;
        _this.r = 0;
        _this.p = false;
        _this.q = new Dictionary$2(String_$type, List$1.$.specialize(String_$type), 0);
        _this.o = a;
        return _this;
    }
    TSCodeGeneratingComponentRendererModuleEmitter.prototype.n = function () {
        _super.prototype.n.call(this);
        this.r = 0;
    };
    Object.defineProperty(TSCodeGeneratingComponentRendererModuleEmitter.prototype, "t", {
        get: function () {
            switch (this.o) {
                case 1: return "Igx";
                case 2: return "Igr";
                case 3: return "Igc";
            }
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TSCodeGeneratingComponentRendererModuleEmitter.prototype, "s", {
        get: function () {
            switch (this.o) {
                case 1: return "angular";
                case 2: return "react";
                case 3: return "webcomponents";
            }
            return "";
        },
        enumerable: true,
        configurable: true
    });
    TSCodeGeneratingComponentRendererModuleEmitter.prototype.k = function (a) {
        _super.prototype.k.call(this, a);
        if (a == "withDescriptions") {
            this.p = true;
            return;
        }
        var b = "igniteui-" + this.s + "-core";
        var c = "";
        var d = a.split('/');
        if (d.length == 1) {
            c = d[0];
        }
        else {
            b = d[0];
            b = "igniteui-" + this.s + "-" + b;
            c = d[1];
        }
        if (!this.q.containsKey(b)) {
            this.q.addItem(b, new List$1(String_$type, 0));
        }
        var e = this.q.item(b);
        if (this.r > 0) {
            this.d.k(",");
        }
        this.d.j(this.t + c);
        e.add(this.t + c);
        if (this.p) {
            if (this.r == 0) {
                this.c.k("private _componentRenderer: ComponentRenderer = null;");
                this.c.k("public get renderer(): ComponentRenderer {");
                this.c.h();
                this.c.k("if (this._componentRenderer == null) {");
                this.c.h();
                this.c.k("this._componentRenderer = new ComponentRenderer();");
                this.c.k("var context = this._componentRenderer.context;");
                this.g.addPackageImport("igniteui-" + this.s + "-core", "ComponentRenderer");
            }
            var f = c;
            if (stringEndsWith(f, "Module")) {
                f = f.substr(0, f.length - ("Module").length);
                f += "DescriptionModule";
            }
            this.g.addPackageImport("igniteui-" + this.s + "-core", f);
            this.c.k(f + ".register(context);");
        }
        this.r++;
    };
    TSCodeGeneratingComponentRendererModuleEmitter.prototype.m = function () {
        var e_1, _a, e_2, _b;
        _super.prototype.m.call(this);
        try {
            for (var _c = tslib_1.__values(fromEnum(this.q.keys)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var a = _d.value;
                var b = a;
                var c = this.q.item(a);
                try {
                    for (var _e = (e_2 = void 0, tslib_1.__values(fromEnum(c))), _f = _e.next(); !_f.done; _f = _e.next()) {
                        var d = _f.value;
                        this.h.addPackageImport(b, d);
                    }
                }
                catch (e_2_1) {
                    e_2 = { error: e_2_1 };
                }
                finally {
                    try {
                        if (_f && !_f.done && (_b = _e.return))
                            _b.call(_e);
                    }
                    finally {
                        if (e_2)
                            throw e_2.error;
                    }
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        if (this.p) {
            this.c.f();
            this.c.k("}");
            this.c.k("return this._componentRenderer");
            this.c.f();
            this.c.k("}");
        }
    };
    TSCodeGeneratingComponentRendererModuleEmitter.$t = markType(TSCodeGeneratingComponentRendererModuleEmitter, 'TSCodeGeneratingComponentRendererModuleEmitter', CodeGeneratingComponentRendererModuleEmitter.$);
    return TSCodeGeneratingComponentRendererModuleEmitter;
}(CodeGeneratingComponentRendererModuleEmitter));
export { TSCodeGeneratingComponentRendererModuleEmitter };

==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/TSCodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { CodeGeneratingComponentRendererModuleEmitter } from "./CodeGeneratingComponentRendererModuleEmitter";
import { Dictionary$2 } from "./Dictionary$2";
import { List$1 } from "./List$1";
import { String_$type, fromEnum, markType } from "./type";
import { stringEndsWith } from "./string";
/**
 * @hidden
 */
var TSCodeGeneratingComponentRendererModuleEmitter = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TSCodeGeneratingComponentRendererModuleEmitter, _super);
    function TSCodeGeneratingComponentRendererModuleEmitter(a, b, c) {
        var _this = _super.call(this, b, c) || this;
        _this.p = 0;
        _this.s = 0;
        _this.q = false;
        _this.r = new Dictionary$2(String_$type, List$1.$.specialize(String_$type), 0);
        _this.p = a;
        return _this;
    }
    TSCodeGeneratingComponentRendererModuleEmitter.prototype.o = function () {
        _super.prototype.o.call(this);
        this.s = 0;
    };
    Object.defineProperty(TSCodeGeneratingComponentRendererModuleEmitter.prototype, "u", {
        get: function () {
            switch (this.p) {
                case 1: return "Igx";
                case 2: return "Igr";
                case 3: return "Igc";
            }
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TSCodeGeneratingComponentRendererModuleEmitter.prototype, "t", {
        get: function () {
            switch (this.p) {
                case 1: return "angular";
                case 2: return "react";
                case 3: return "webcomponents";
            }
            return "";
        },
        enumerable: true,
        configurable: true
    });
    TSCodeGeneratingComponentRendererModuleEmitter.prototype.l = function (a) {
        _super.prototype.l.call(this, a);
        if (a == "withDescriptions") {
            this.q = true;
            return;
        }
        var b = "igniteui-" + this.t + "-core";
        var c = "";
        var d = a.split('/');
        if (d.length == 1) {
            c = d[0];
            this.j.addPackageRef(c);
        }
        else {
            b = d[0];
            this.j.addPackageRef(b);
            b = "igniteui-" + this.t + "-" + b;
            c = d[1];
        }
        if (!this.r.containsKey(b)) {
            this.r.addItem(b, new List$1(String_$type, 0));
        }
        var e = this.r.item(b);
        if (this.s > 0) {
            this.d.k(",");
        }
        this.d.j(this.u + c);
        e.add(this.u + c);
        if (this.q) {
            if (this.s == 0) {
                this.c.k("private _componentRenderer: ComponentRenderer = null;");
                this.c.k("public get renderer(): ComponentRenderer {");
                this.c.h();
                this.c.k("if (this._componentRenderer == null) {");
                this.c.h();
                this.c.k("this._componentRenderer = new ComponentRenderer();");
                this.c.k("var context = this._componentRenderer.context;");
                this.g.addPackageImport("igniteui-" + this.t + "-core", "ComponentRenderer");
            }
            var f = c;
            if (stringEndsWith(f, "Module")) {
                f = f.substr(0, f.length - ("Module").length);
                f += "DescriptionModule";
            }
            this.g.addPackageImport("igniteui-" + this.t + "-core", f);
            this.c.k(f + ".register(context);");
        }
        this.s++;
    };
    TSCodeGeneratingComponentRendererModuleEmitter.prototype.n = function () {
        var e_1, _a, e_2, _b;
        _super.prototype.n.call(this);
        try {
            for (var _c = tslib_1.__values(fromEnum(this.r.keys)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var a = _d.value;
                var b = a;
                var c = this.r.item(a);
                try {
                    for (var _e = (e_2 = void 0, tslib_1.__values(fromEnum(c))), _f = _e.next(); !_f.done; _f = _e.next()) {
                        var d = _f.value;
                        this.h.addPackageImport(b, d);
                    }
                }
                catch (e_2_1) {
                    e_2 = { error: e_2_1 };
                }
                finally {
                    try {
                        if (_f && !_f.done && (_b = _e.return))
                            _b.call(_e);
                    }
                    finally {
                        if (e_2)
                            throw e_2.error;
                    }
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        if (this.q) {
            this.c.f();
            this.c.k("}");
            this.c.k("return this._componentRenderer;");
            this.c.f();
            this.c.k("}");
        }
    };
    TSCodeGeneratingComponentRendererModuleEmitter.$t = markType(TSCodeGeneratingComponentRendererModuleEmitter, 'TSCodeGeneratingComponentRendererModuleEmitter', CodeGeneratingComponentRendererModuleEmitter.$);
    return TSCodeGeneratingComponentRendererModuleEmitter;
}(CodeGeneratingComponentRendererModuleEmitter));
export { TSCodeGeneratingComponentRendererModuleEmitter };
